<!--设备监测 -->
<template>
    <page-container>
        <div class="device-overview">
            <div class="left-menu-container">
                <j-input-search
                    v-model:value="searchKey"
                    placeholder="请输入关键字"
                    style="margin: 16px 11px 0 11px; width: 225px"
                    @search="onSearch"
                    @pressEnter="onSearch"
                />
                <j-menu v-model:selectedKeys="current" mode="horizontal">
                    <j-menu-item key="grid-view">
                        <template #icon>
                            <AIcon type="AppstoreOutlined" />
                        </template>
                        宫格视图
                    </j-menu-item>
                    <j-menu-item key="list-view">
                        <template #icon>
                            <AIcon type="BarsOutlined" />
                        </template>
                        列表视图
                    </j-menu-item>
                </j-menu>
                <j-collapse v-model:activeKey="activeKey" ghost>
                    <j-collapse-panel
                        v-for="menu in menuList"
                        :key="menu.key"
                        :header="menu.title"
                    >
                        <div :class="'menu-' + current">
                            <div
                                v-for="(item, index) in menu.children"
                                :key="index"
                                :class="[
                                    'menu-item',
                                    selectedMenuId == item.id ? 'active' : '',
                                ]"
                                @click="
                                    selectedMenuId = item.id;
                                    layoutTypeId = item.typeId;
                                    currentNode = item;
                                    deviceInfo.updateDeviceInfo(item.typeId);
                                "
                            >
                                <img :src="getImage(item.iconUrl)" alt="" />
                                <div>
                                    {{ item.title }}
                                </div>
                            </div>
                        </div>
                    </j-collapse-panel>
                </j-collapse>
            </div>
            <div class="right-content-container">
                <template v-if="layoutTypeId == 1101">
                    <MJG :ndata="currentNode" />
                </template>
                <template v-if="layoutTypeId == 1921">
                    <JMKT :ndata="currentNode"/>
                </template>
                <template v-if="layoutTypeId == 1911">
                    <HSYTJ :ndata="currentNode"/>
                </template>
                <template v-if="layoutTypeId == 1901">
                    <XFJ :ndata="currentNode"/>
                </template>
                <template v-if="layoutTypeId == 1421">
                    <WSJ :ndata="currentNode"/>
                </template>
                <template v-if="layoutTypeId == 1411">
                    <KQJC :ndata="currentNode"/>
                </template>
                <template v-if="layoutTypeId == 1401">
                    <LSJC :ndata="currentNode"/>
                </template>
                <template v-if="layoutTypeId == 1301">
                    <MJ :ndata="currentNode"/>
                </template>
                <template v-if="layoutTypeId == 1321">
                    <JKXT :ndata="currentNode"/>
                </template>
                <template v-if="layoutTypeId == 1211">
                    <XFXT />
                </template>
                <template v-if="layoutTypeId == 1201">
                    <YWTC :ndata="currentNode"/>
                </template>
            </div>
        </div>
    </page-container>
</template>
<script lang="ts" name="Category" setup>
import { getImage } from '@/utils/comm';
import MJG from './layout/MJG.vue'; // 密集柜
import WSJ from './layout/WSJ.vue'; // 温湿计
import JKXT from './layout/JKXT.vue'; // 监控系统
import JMKT from './layout/JMKT.vue'; // 精密空调
import HSYTJ from './layout/HSYTJ.vue'; // 恒湿一体机
import XFJ from './layout/XFJ.vue'; // 新风机
import KQJC from './layout/KQJC.vue'; // 空气质量监测
import LSJC from './layout/LSJC.vue'; // 漏水监测
import MJ from './layout/MJ.vue'; // 门禁
import XFXT from './layout/XFXT.vue'; // 消防系统
import YWTC from './layout/YWTC.vue'; // 烟雾探测
import { useDeviceInfo } from '@/store/device';

const deviceInfo = useDeviceInfo()
const searchKey = ref<string>('');
const current = ref<string[]>(['list-view']);
const activeKey = ref(['1']);
const menuList = ref();
const selectedMenuId = ref('id0001');
const layoutTypeId = ref(1921); // 1101: 密集柜
const currentNode = ref({}); //当前选中的节点

onMounted(() => {
    menuList.value = [
        {
            key: 1,
            title: '库房设备',
            children: [
                {
                    id: 'id0001',
                    title: '精密空调',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: 1921,
                    deviceId: '1685504304644624384'
                },
                {
                    id: 'id0002',
                    title: '恒湿一体机',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: 1911,
                },
                {
                    id: 'id0003',
                    title: '新风机',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: 1901,
                },
            ],
        },
        {
            key: 2,
            title: '环境监测',
            children: [
                {
                    id: 'id0004',
                    title: '温湿计',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: 1421,
                    productType:'WSJ',
                    deviceId:'1690590969670762496'
                },
                {
                    id: 'id0005',
                    title: '空气质量监测',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: 1411,
                    productType:'KQJC',
                    deviceId:'1680042040279568384'
                },
                {
                    id: 'id0006',
                    title: '漏水监测',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: 1401,
                },
            ],
        },
        {
            key: 3,
            title: '安防系统',
            children: [
                {
                    id: 'id0007',
                    title: '监控系统',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: 1321,
                },
                {
                    id: 'id0008',
                    title: '门禁-西门',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: 1301,
                },
                {
                    id: 'id0009',
                    title: '门禁-东门',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: 1301,
                },
            ],
        },
        {
            key: 4,
            title: '消防系统',
            children: [
                {
                    id: 'id0010',
                    title: '消防系统',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: 1211,
                },
                {
                    id: 'id0011',
                    title: '烟雾探测',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: 1201,
                },
            ],
        },
        {
            key: 5,
            title: '密集架',
            children: [
                {
                    id: 'id0012',
                    title: '306-密集架',
                    productType:'MJJ',
                    deviceId:'1677103799506132992',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: '1101',
                },
                {
                    id: 'id0013',
                    title: '308-密集架',
                    productType:'MJJ',
                    deviceId:'1677104132751974400',
                    iconUrl: '/home/h-08.png',
                    status: 1,
                    typeId: '1101',
                },
            ],
        },
    ];
});

const onSearch = (searchValue: string) => {
    console.log('use value', searchValue);
    console.log('or use this.value', searchKey.value);
};
</script>
<style lang="less">
@import url('./index.less');
</style>
